@@ -349,16 +349,15 @@ SQLRETURN DBC::connect(DataSource *dsrc)
     mysql_options(mysql, MYSQL_PLUGIN_DIR,
                   ds_get_utf8attr(dsrc->plugin_dir, &dsrc->plugin_dir8));
   }
+
 #ifdef WIN32
   else
   {
-    static const char *default_plugin_location =
-#if _WIN64
-    "C:/Program Files/MySQL/Connector ODBC 8.0/plugin";
-#else
-    "C:/Program Files (x86)/MySQL/Connector ODBC 8.0/plugin";
-#endif
-    mysql_options(mysql, MYSQL_PLUGIN_DIR, default_plugin_location);
+    /*
+      If plugin directory is not set we can use the dll location
+      for a better chance of finding plugins.
+    */
+    mysql_options(mysql, MYSQL_PLUGIN_DIR, default_plugin_location.c_str());
   }
 #endif
 
