@@ -43,23 +43,24 @@
 SQLRETURN do_query(STMT *stmt,char *query, SQLULEN query_length)
 {
     int error= SQL_ERROR, native_error= 0;
+    LOCK_STMT_DEFER(stmt);
 
     if (!query)
     {
       /* Probably error from insert_param */
-      goto skip_unlock_exit;
+      goto exit;
     }
 
     if(!SQL_SUCCEEDED(set_sql_select_limit(stmt->dbc,
                       stmt->stmt_options.max_rows, TRUE)))
     {
       /* The error is set for DBC, copy it into STMT */
-      set_stmt_error(stmt, stmt->dbc->error.sqlstate,
+      stmt->set_error(stmt->dbc->error.sqlstate,
                      stmt->dbc->error.message,
                      stmt->dbc->error.native_error);
 
       /* if setting sql_select_limit fails, the query will probably fail anyway too */
-      goto skip_unlock_exit;
+      goto exit;
     }
 
     if (query_length == 0)
@@ -68,15 +69,16 @@ SQLRETURN do_query(STMT *stmt,char *query, SQLULEN query_length)
     }
 
     MYLOG_QUERY(stmt, query);
-    myodbc_mutex_lock(&stmt->dbc->lock);
+    DO_LOCK_STMT();
 
     if ( check_if_server_is_alive( stmt->dbc ) )
     {
-      set_stmt_error( stmt, "08S01" /* "HYT00" */,
-                      mysql_error(&stmt->dbc->mysql),
-                      mysql_errno(&stmt->dbc->mysql));
+      stmt->set_error("08S01" /* "HYT00" */,
+                      mysql_error(stmt->dbc->mysql),
+                      mysql_errno(stmt->dbc->mysql));
+
       translate_error(stmt->error.sqlstate, MYERR_08S01 /* S1000 */,
-                      mysql_errno(&stmt->dbc->mysql));
+                      mysql_errno(stmt->dbc->mysql));
       goto exit;
     }
 
@@ -105,7 +107,7 @@ SQLRETURN do_query(STMT *stmt,char *query, SQLULEN query_length)
       scroller_move(stmt);
       MYLOG_QUERY(stmt, stmt->scroller.query);
 
-      native_error= mysql_real_query(&stmt->dbc->mysql, stmt->scroller.query,
+      native_error = mysql_real_query(stmt->dbc->mysql, stmt->scroller.query,
                                   (unsigned long)stmt->scroller.query_len);
     }
       /* Not using ssps for scroller so far. Relaxing a bit condition
@@ -121,7 +123,7 @@ SQLRETURN do_query(STMT *stmt,char *query, SQLULEN query_length)
       }
       else
       {
-        set_stmt_error(stmt, "HY000",
+        stmt->set_error("HY000",
                        mysql_stmt_error(stmt->ssps),
                        mysql_stmt_errno(stmt->ssps));
 
@@ -138,20 +140,27 @@ SQLRETURN do_query(STMT *stmt,char *query, SQLULEN query_length)
       /* Need to close ps handler if it is open as our relsult will be generated
          by direct execution. and ps handler may create some chaos */
       ssps_close(stmt);
-      native_error= mysql_real_query(&stmt->dbc->mysql,query,query_length);
+
+      native_error = stmt->bind_query_attrs(false);
+      if (native_error == SQL_ERROR)
+      {
+        error = SQL_ERROR;
+        goto exit;
+      }
+
+      native_error= mysql_real_query(stmt->dbc->mysql,query,query_length);
     }
 
     MYLOG_QUERY(stmt, "query has been executed");
 
     if (native_error)
     {
-      MYLOG_QUERY(stmt, mysql_error(&stmt->dbc->mysql));
-      set_stmt_error(stmt, "HY000", mysql_error(&stmt->dbc->mysql),
-                     mysql_errno(&stmt->dbc->mysql));
+      MYLOG_QUERY(stmt, mysql_error(stmt->dbc->mysql));
+      stmt->set_error("HY000");
 
       /* For some errors - translating to more appropriate status */
       translate_error(stmt->error.sqlstate, MYERR_S1000,
-                      mysql_errno(&stmt->dbc->mysql));
+                      mysql_errno(stmt->dbc->mysql));
       goto exit;
     }
 
@@ -160,8 +169,7 @@ SQLRETURN do_query(STMT *stmt,char *query, SQLULEN query_length)
       /* Query was supposed to return result, but result is NULL*/
       if (returned_result(stmt))
       {
-        stmt->set_error( MYERR_S1000, mysql_error(&stmt->dbc->mysql),
-                mysql_errno(&stmt->dbc->mysql));
+        stmt->set_error(MYERR_S1000);
         goto exit;
       }
       else /* Query was not supposed to return a result */
@@ -173,13 +181,20 @@ SQLRETURN do_query(STMT *stmt,char *query, SQLULEN query_length)
       }
     }
 
+    if (bind_result(stmt) || get_result(stmt))
+    {
+        stmt->set_error(MYERR_S1000);
+        goto exit;
+    }
+    /* Caching row counts for queries returning resultset as well */
+    //update_affected_rows(stmt);
+    fix_result_types(stmt);
+
     /* If the only resultset is OUT params, then we can only detect
        corresponding server_status right after execution.
        If the RS is OUT params - we do not need to do store_result obviously */
     if (IS_PS_OUT_PARAMS(stmt))
     {
-      /* For out parameters resultset we do not need to get result and bind it */
-      fix_result_types(stmt);
       /* This status(SERVER_PS_OUT_PARAMS) can be only if we used PS */
       ssps_get_out_params(stmt);
 
@@ -189,25 +204,12 @@ SQLRETURN do_query(STMT *stmt,char *query, SQLULEN query_length)
         goto exit;
       }
     }
-    else
-    {
-      if (bind_result(stmt) || get_result(stmt))
-      {
-          stmt->set_error( MYERR_S1000, mysql_error(&stmt->dbc->mysql),
-                  mysql_errno(&stmt->dbc->mysql));
-          goto exit;
-      }
-      /* Caching row counts for queries returning resultset as well */
-      //update_affected_rows(stmt);
-      fix_result_types(stmt);
-    }
+
 
     error= SQL_SUCCESS;
 
 exit:
-    myodbc_mutex_unlock(&stmt->dbc->lock);
 
-skip_unlock_exit:
     if (query != GET_QUERY(&stmt->query))
     {
       x_free(query);
@@ -244,14 +246,15 @@ SQLRETURN insert_params(STMT *stmt, SQLULEN row, char **finalquery,
   char *query= GET_QUERY(&stmt->query);
   uint i,length, had_info= 0;
   SQLRETURN rc= SQL_SUCCESS;
+  DECLARE_LOCALE_HANDLE
 
-  int mutex_was_locked= myodbc_mutex_trylock(&stmt->dbc->lock);
+  LOCK_STMT(stmt);
 
   //to = stmt->buf() + (finalquery_length != NULL ? *finalquery_length : 0);
 
   if (!stmt->dbc->ds->dont_use_set_locale)
   {
-    setlocale(LC_NUMERIC, "C");  /* force use of '.' as decimal point */
+    __LOCALE_SET("C"); /* force use of '.' as decimal point */
   }
 
   if (adjust_param_bind_array(stmt) )
@@ -271,7 +274,7 @@ SQLRETURN insert_params(STMT *stmt, SQLULEN row, char **finalquery,
     {
       rc= stmt->set_error( MYERR_07001,
           "The number of parameter markers is not equal "
-          "to he number of parameters provided",0);
+          "to the number of parameters provided",0);
       goto error;
     }
 
@@ -346,14 +349,9 @@ SQLRETURN insert_params(STMT *stmt, SQLULEN row, char **finalquery,
     }
   }
 
-  if (!mutex_was_locked)
-  {
-    myodbc_mutex_unlock(&stmt->dbc->lock);
-  }
-
   if (!stmt->dbc->ds->dont_use_set_locale)
   {
-    setlocale(LC_NUMERIC,default_locale);
+    __LOCALE_RESTORE();
   }
 
 
@@ -362,12 +360,10 @@ SQLRETURN insert_params(STMT *stmt, SQLULEN row, char **finalquery,
 
 memerror:      /* Too much data */
   rc= stmt->set_error(MYERR_S1001,NULL,4001);
+
 error:
-  /* ! was _already_ locked, when we tried to lock */
-  if (!mutex_was_locked)
-    myodbc_mutex_unlock(&stmt->dbc->lock);
   if (!stmt->dbc->ds->dont_use_set_locale)
-    setlocale(LC_NUMERIC,default_locale);
+    __LOCALE_RESTORE();
   return rc;
 }
 
@@ -466,7 +462,7 @@ static
 BOOL put_param_value(STMT *stmt, MYSQL_BIND *bind,
                      const char * value, unsigned long length)
 {
-  if (ssps_used(stmt))
+  if (bind)
   {
     return bind_param(bind, value, length, MYSQL_TYPE_STRING);
   }
@@ -484,7 +480,7 @@ SQLRETURN check_c2sql_conversion_supported(STMT *stmt, DESCREC *aprec, DESCREC *
   if (aprec->type == SQL_DATETIME && iprec->type == SQL_INTERVAL
    || aprec->type == SQL_INTERVAL && iprec->type == SQL_DATETIME)
   {
-    return set_stmt_error(stmt, "07006", "Conversion is not supported", 0);
+    return stmt->set_error("07006", "Conversion is not supported", 0);
   }
 
   switch (aprec->concise_type)
@@ -501,7 +497,7 @@ SQLRETURN check_c2sql_conversion_supported(STMT *stmt, DESCREC *aprec, DESCREC *
     case SQL_C_INTERVAL_DAY_TO_MINUTE:
     case SQL_C_INTERVAL_DAY_TO_SECOND:
     case SQL_C_INTERVAL_MINUTE_TO_SECOND:
-      return set_stmt_error(stmt, "07006", "Conversion is not supported by driver", 0);
+      return stmt->set_error("07006", "Conversion is not supported by driver", 0);
   }
 
   return SQL_SUCCESS;
@@ -542,9 +538,9 @@ SQLRETURN convert_c_type2str(STMT *stmt, SQLSMALLINT ctype, DESCREC *iprec,
 
 
         if (has_utf8_maxlen4 &&
-            !is_minimum_version(stmt->dbc->mysql.server_version, "5.5.3"))
+            !is_minimum_version(stmt->dbc->mysql->server_version, "5.5.3"))
         {
-          return set_stmt_error(stmt, "HY000",
+          return stmt->set_error("HY000",
                                 "Server does not support 4-byte encoded "
                                 "UTF8 characters.", 0);
         }
@@ -635,7 +631,7 @@ SQLRETURN convert_c_type2str(STMT *stmt, SQLSMALLINT ctype, DESCREC *iprec,
 
         if (time->hour > 23)
         {
-          return set_stmt_error(stmt, "22008", "Not a valid time value supplied", 0);
+          return stmt->set_error("22008", "Not a valid time value supplied", 0);
         }
 
         *length= sprintf(buff, "%02d:%02d:%02d",
@@ -703,7 +699,7 @@ SQLRETURN convert_c_type2str(STMT *stmt, SQLSMALLINT ctype, DESCREC *iprec,
         /* TODO no way to return an error here? */
         if (trunc == SQLNUM_TRUNC_FRAC)
         {/* 01S07 SQL_SUCCESS_WITH_INFO */
-          set_stmt_error(stmt, "01S07", "Fractional truncation", 0);
+          stmt->set_error("01S07", "Fractional truncation", 0);
           return SQL_SUCCESS_WITH_INFO;
         }
         else if (trunc == SQLNUM_TRUNC_WHOLE)
@@ -753,7 +749,7 @@ SQLRETURN convert_c_type2str(STMT *stmt, SQLSMALLINT ctype, DESCREC *iprec,
       }
     /* If we are missing processing of some valid C type. Probably means a bug elsewhere */
     default:
-      return set_stmt_error(stmt, "07006",
+      return stmt->set_error("07006",
                "Conversion is not supported", 0);
   }
   return SQL_SUCCESS;
@@ -761,6 +757,41 @@ SQLRETURN convert_c_type2str(STMT *stmt, SQLSMALLINT ctype, DESCREC *iprec,
 
 #define TIME_FIELDS_NONZERO(ts) (ts.hour||ts.minute||ts.second||ts.fraction)
 
+static const std::string ts_chars{"0123456789-:"};
+
+inline bool is_ts_char(char c)
+{
+  return std::string::npos != ts_chars.find(c);
+}
+
+
+/*
+  Returns the date-time component of ODBC string like
+  {dt yyyy-mm-dd hh:mm:ss}
+*/
+const char *get_date_time_substr(const char *data, long &len)
+{
+  const char* d_start = data;
+  long idx = 0;
+  while(len && !is_ts_char(*d_start))
+  {
+    --len;
+    ++d_start;
+  }
+
+  if (!len)
+    return nullptr;
+
+  const char* d_end = d_start + len - 1;
+  while(d_start < d_end && !is_ts_char(*d_end))
+  {
+    --len;
+    --d_end;
+  }
+
+  return d_start;
+}
+
 /*
   Add the value of parameter to a string buffer.
 
@@ -853,15 +884,15 @@ SQLRETURN insert_param(STMT *stmt, MYSQL_BIND *bind, DESC* apd,
              /* empty values mean it's an unbound column */
              (*octet_length_ptr == 0 &&
               aprec->concise_type == SQL_C_DEFAULT &&
-              aprec->par.value == NULL))
+              aprec->par.val() == NULL))
     {
       put_default_value(stmt, bind);
       return SQL_SUCCESS;
     }
     else if (IS_DATA_AT_EXEC(octet_length_ptr))
     {
-        length= aprec->par.value_length;
-        if ( !(data= aprec->par.value) )
+        length= aprec->par.val_length();
+        if ( !(data= aprec->par.val()) )
         {
           put_default_value(stmt, bind);
           return SQL_SUCCESS;
@@ -908,10 +939,17 @@ SQLRETURN insert_param(STMT *stmt, MYSQL_BIND *bind, DESC* apd,
         if (data[0] == '{')       /* Of type {d date } */
         {
           /* TODO: check if we need to check for truncation here as well? */
-          if (bind != NULL && ssps_used(stmt))
+          if (bind != NULL)
           {
-            if (bind_param(bind, data, length,
-                        map_sql2mysql_type(iprec->concise_type)))
+            /* First the datetime has to be filtered out of the brackets
+               and other stuff. The validity of the format is up to the
+               user.
+            */
+            const char *tt = get_date_time_substr(data, length);
+
+            /* The length parameter is changed by get_date_time_substr()
+               because it is passed as a reference */
+            if (bind_param(bind, tt, length, MYSQL_TYPE_STRING))
             {
               goto memerror;
             }
@@ -948,7 +986,7 @@ SQLRETURN insert_param(STMT *stmt, MYSQL_BIND *bind, DESC* apd,
             */
           if (!stmt->dbc->ds->no_date_overflow && TIME_FIELDS_NONZERO(ts))
           {
-            return set_stmt_error(stmt, "22008", "Date overflow", 0);
+            return stmt->set_error("22008", "Date overflow", 0);
           }
         }
         /* else _binary introducer for binary data */
@@ -956,7 +994,7 @@ SQLRETURN insert_param(STMT *stmt, MYSQL_BIND *bind, DESC* apd,
       case SQL_VARBINARY:
       case SQL_LONGVARBINARY:
         {
-          if (bind != NULL && ssps_used(stmt))
+          if (bind != NULL)
           {
             /* i guess for ssps we do not need introducer */
             convert= 0;
@@ -983,7 +1021,7 @@ SQLRETURN insert_param(STMT *stmt, MYSQL_BIND *bind, DESC* apd,
           if (aprec->concise_type == SQL_C_WCHAR &&
               dbc->cxn_charset_info->number != UTF8_CHARSET_NUMBER)
           {
-            if (bind != NULL && ssps_used(stmt))
+            if (bind != NULL)
             {
                 if (bind_param(bind, data, length, MYSQL_TYPE_BLOB))
               {
@@ -1001,7 +1039,7 @@ SQLRETURN insert_param(STMT *stmt, MYSQL_BIND *bind, DESC* apd,
                     dbc->cxn_charset_info->number !=
                     dbc->ansi_charset_info->number)
           {
-            if (bind != NULL && ssps_used(stmt))
+            if (bind != NULL)
             {
               if (bind_param(bind, data, length, MYSQL_TYPE_BLOB))
               {
@@ -1026,7 +1064,7 @@ SQLRETURN insert_param(STMT *stmt, MYSQL_BIND *bind, DESC* apd,
             aprec->concise_type != SQL_C_INTERVAL_HOUR_TO_SECOND)
         {
           /* Allow only interval to interval conversion */
-          set_stmt_error(stmt, "07006", "Conversion is not supported", 0);
+          stmt->set_error("07006", "Conversion is not supported", 0);
         }
         else
         {
@@ -1046,17 +1084,17 @@ SQLRETURN insert_param(STMT *stmt, MYSQL_BIND *bind, DESC* apd,
 
           if (time->hour > 23)
           {
-            return set_stmt_error(stmt, "22008", "Not a valid time value supplied", 0);
+            return stmt->set_error("22008", "Not a valid time value supplied", 0);
           }
           if (time->fraction)
           {
             /* fractional seconds truncated, need to set correct sqlstate 22008
             http://msdn.microsoft.com/en-us/library/ms709385%28v=vs.85%29.aspx */
 
-            return set_stmt_error(stmt, "22008", "Fractional truncation", 0);
+            return stmt->set_error("22008", "Fractional truncation", 0);
           }
 
-          if (bind != NULL && ssps_used(stmt))
+          if (bind != NULL)
           {
             length= sprintf(buff, "%02d:%02d:%02d", time->hour, time->minute, time->second);
           }
@@ -1083,7 +1121,7 @@ SQLRETURN insert_param(STMT *stmt, MYSQL_BIND *bind, DESC* apd,
           if (fraction)
           {
             /* truncation need SQL_ERROR and sqlstate 22008*/
-            return set_stmt_error(stmt, "22008", "Fractional truncation", 0);
+            return stmt->set_error("22008", "Fractional truncation", 0);
           }
 
           time= str_to_time_as_long(data,length);
@@ -1091,10 +1129,10 @@ SQLRETURN insert_param(STMT *stmt, MYSQL_BIND *bind, DESC* apd,
 
           if (hours > 23)
           {
-            return set_stmt_error(stmt, "22008", "Not a valid time value supplied", 0);
+            return stmt->set_error("22008", "Not a valid time value supplied", 0);
           }
 
-          if (bind != NULL && ssps_used(stmt))
+          if (bind != NULL)
           {
             length= sprintf(buff, "%02d:%02d:%02d",
                   hours,
@@ -1119,7 +1157,7 @@ SQLRETURN insert_param(STMT *stmt, MYSQL_BIND *bind, DESC* apd,
 
       case SQL_BIT:
         {
-          if (bind != NULL && ssps_used(stmt))
+          if (bind != NULL)
           {
             char bit_val= atoi(data)!= 0 ? 1 : 0;
             /* Generic ODBC supports only BIT(1) */
@@ -1188,7 +1226,7 @@ SQLRETURN insert_param(STMT *stmt, MYSQL_BIND *bind, DESC* apd,
         }
     }
 
-    if (bind != NULL && ssps_used(stmt) && stmt->setpos_op == 0)
+    if (bind != NULL && stmt->setpos_op == 0)
     {
       bind_param(bind, data, length, MYSQL_TYPE_STRING);
     }
@@ -1218,7 +1256,7 @@ SQLRETURN insert_param(STMT *stmt, MYSQL_BIND *bind, DESC* apd,
           goto memerror;
         }
 
-        size_t added = mysql_real_escape_string(&dbc->mysql, stmt->endbuf(), data, length);
+        size_t added = mysql_real_escape_string(dbc->mysql, stmt->endbuf(), data, length);
         stmt->buf_add_pos(added);
         stmt->add_to_buffer("'", 1);
       }
@@ -1246,30 +1284,30 @@ memerror:
   @purpose : positioned cursor update/delete
 */
 
-SQLRETURN do_my_pos_cursor( STMT *pStmt, STMT *pStmtCursor )
+
+SQLRETURN do_my_pos_cursor_std( STMT *pStmt, STMT *pStmtCursor )
 {
   char *          pszQuery= GET_QUERY(&pStmt->query);
-  DYNAMIC_STRING  dynQuery;
+  std::string     query;
   SQLRETURN       nReturn;
 
   if ( pStmt->error.native_error == ER_INVALID_CURSOR_NAME )
   {
-      return set_stmt_error( pStmt, "HY000", "ER_INVALID_CURSOR_NAME", 0 );
+      return pStmt->set_error("HY000", "ER_INVALID_CURSOR_NAME", 0 );
   }
 
   while ( isspace( *pszQuery ) )
       ++pszQuery;
 
-  if ( myodbc_init_dynamic_string( &dynQuery, pszQuery, 1024, 1024 ) )
-      return pStmt->set_error(MYERR_S1001, NULL, 4001 );
+  query = pszQuery;
 
   if ( !myodbc_casecmp( pszQuery, "delete", 6 ) )
   {
-      nReturn = my_pos_delete( pStmtCursor, pStmt, 1, &dynQuery );
+      nReturn = my_pos_delete_std( pStmtCursor, pStmt, 1, query );
   }
   else if ( !myodbc_casecmp( pszQuery, "update", 6 ) )
   {
-      nReturn = my_pos_update( pStmtCursor, pStmt, 1, &dynQuery );
+      nReturn = my_pos_update_std( pStmtCursor, pStmt, 1, query );
   }
   else
   {
@@ -1279,8 +1317,6 @@ SQLRETURN do_my_pos_cursor( STMT *pStmt, STMT *pStmtCursor )
   if ( SQL_SUCCEEDED( nReturn ) )
       pStmt->state = ST_EXECUTED;
 
-  myodbc_dynstr_free( &dynQuery );
-
   return( nReturn );
 }
 
@@ -1338,7 +1374,7 @@ SQLRETURN my_SQLExecute( STMT *pStmt )
   int         dae_rec, is_select_stmt, one_of_params_not_succeded= 0;
   int         connection_failure= 0;
   STMT       *pStmtCursor = pStmt;
-  SQLRETURN   rc;
+  SQLRETURN   rc = 0;
   SQLULEN     row, length= 0;
 
   SQLUSMALLINT *param_operation_ptr= NULL, *param_status_ptr= NULL, *lastError= NULL;
@@ -1379,7 +1415,7 @@ SQLRETURN my_SQLExecute( STMT *pStmt )
     /* Chop off the 'WHERE CURRENT OF ...' - doing it a hard way...*/
     *cursor_pos= '\0';
 
-    return do_my_pos_cursor(pStmt, pStmtCursor);
+    return do_my_pos_cursor_std(pStmt, pStmtCursor);
   }
 
   my_SQLFreeStmt((SQLHSTMT)pStmt,MYSQL_RESET_BUFFERS);
@@ -1401,14 +1437,7 @@ SQLRETURN my_SQLExecute( STMT *pStmt )
     *pStmt->ipd->rows_processed_ptr= (SQLULEN)0;
   }
 
-  /* Locking if we have params array for "SELECT" statemnt */
-  /* if param_count is zero, the rest probably are artifacts(not reset
-     attributes) from a previously executed statement. besides this lock
-     is not needed when there are no params*/
-  if (pStmt->param_count && pStmt->apd->array_size > 1 && is_select_stmt)
-  {
-    myodbc_mutex_lock(&pStmt->dbc->lock);
-  }
+  LOCK_STMT(pStmt);
 
   for (row= 0; row < pStmt->apd->array_size; ++row)
   {
@@ -1444,11 +1473,6 @@ SQLRETURN my_SQLExecute( STMT *pStmt )
         if (param_status_ptr)
           *param_status_ptr= SQL_PARAM_UNUSED;
 
-        /* If this is last paramset - we will miss unlock */
-        if (pStmt->apd->array_size > 1 && is_select_stmt
-            && row == pStmt->apd->array_size - 1)
-          myodbc_mutex_unlock(&pStmt->dbc->lock);
-
         continue;
       }
 
@@ -1460,14 +1484,10 @@ SQLRETURN my_SQLExecute( STMT *pStmt )
       {
         if (pStmt->apd->array_size > 1)
         {
-          rc= set_stmt_error(pStmt, "HYC00", "Parameter arrays "
+          rc= pStmt->set_error("HYC00", "Parameter arrays "
                               "with data at execution are not supported", 0);
           lastError= param_status_ptr;
 
-          /* unlocking since we do break*/
-          if (is_select_stmt)
-            myodbc_mutex_unlock(&pStmt->dbc->lock);
-
           one_of_params_not_succeded= 1;
 
           /* For other errors we continue processing of paramsets
@@ -1506,10 +1526,6 @@ SQLRETURN my_SQLExecute( STMT *pStmt )
 
       if (!SQL_SUCCEEDED(rc))
       {
-        if (pStmt->apd->array_size > 1 && is_select_stmt
-          && row == pStmt->apd->array_size - 1)
-          myodbc_mutex_unlock(&pStmt->dbc->lock);
-
         continue/*return rc*/;
       }
 
@@ -1525,11 +1541,6 @@ SQLRETURN my_SQLExecute( STMT *pStmt )
           pStmt->add_to_buffer(stmtsBinder, binderLength);
           length+= binderLength;
         }
-        else
-        {
-          /* last select statement has been constructed - so releasing lock*/
-          myodbc_mutex_unlock(&pStmt->dbc->lock);
-        }
       }
     }
 
@@ -1639,11 +1650,11 @@ static SQLRETURN select_dae_param_desc(STMT *stmt, DESC **apd, unsigned int *par
       break;
     case DAE_SETPOS_INSERT:
     case DAE_SETPOS_UPDATE:
-      *apd= stmt->setpos_apd;
-      *param_count= stmt->ard->count;
+      *apd= stmt->setpos_apd.get();
+      *param_count= stmt->ard->rcount();
       break;
     default:
-      return set_stmt_error(stmt, "HY010",
+      return stmt->set_error("HY010",
         "Invalid data at exec state", 0);
   }
 
@@ -1683,8 +1694,7 @@ static SQLRETURN find_next_dae_param(STMT *stmt,  SQLPOINTER *token)
                                       apd->bind_type,
                                       default_size, 0);
       }
-      aprec->par.value= NULL;
-      aprec->par.alloced= FALSE;
+      aprec->par.reset();
       aprec->par.is_dae= 1;
 
       return SQL_NEED_DATA;
@@ -1712,14 +1722,12 @@ static SQLRETURN execute_dae(STMT *stmt)
   case DAE_SETPOS_INSERT:
     stmt->dae_type= DAE_SETPOS_DONE;
     rc= my_SQLSetPos((HSTMT)stmt, stmt->setpos_row, SQL_ADD, stmt->setpos_lock);
-    desc_free(stmt->setpos_apd);
-    stmt->setpos_apd= NULL;
+    stmt->setpos_apd.reset();
     break;
   case DAE_SETPOS_UPDATE:
     stmt->dae_type= DAE_SETPOS_DONE;
     rc= my_SQLSetPos((HSTMT)stmt, stmt->setpos_row, SQL_UPDATE, stmt->setpos_lock);
-    desc_free(stmt->setpos_apd);
-    stmt->setpos_apd= NULL;
+    stmt->setpos_apd.reset();
     break;
   }
 
@@ -1801,7 +1809,7 @@ SQLRETURN SQL_API SQLParamData(SQLHSTMT hstmt, SQLPOINTER *prbgValue)
 
       if (mysql_stmt_bind_param(stmt->ssps, (MYSQL_BIND*)stmt->param_bind->buffer))
       {
-        set_stmt_error(stmt, "HY000", mysql_stmt_error(stmt->ssps),
+        stmt->set_error("HY000", mysql_stmt_error(stmt->ssps),
                       mysql_stmt_errno(stmt->ssps));
 
         /* For some errors - translating to more appropriate status */
@@ -1855,7 +1863,7 @@ SQLRETURN SQL_API SQLPutData( SQLHSTMT      hstmt,
   }
   else
   {
-    aprec= desc_get_rec(stmt->setpos_apd, stmt->current_param - 1, FALSE);
+    aprec= desc_get_rec(stmt->setpos_apd.get(), stmt->current_param - 1, FALSE);
   }
 
   if (!aprec)
@@ -1877,12 +1885,7 @@ SQLRETURN SQL_API SQLPutData( SQLHSTMT      hstmt,
 
   if ( cbValue == SQL_NULL_DATA )
   {
-    if ( aprec->par.alloced )
-    {
-      x_free(aprec->par.value);
-    }
-    aprec->par.alloced= FALSE;
-    aprec->par.value= NULL;
+    aprec->par.reset();
     return SQL_SUCCESS;
   }
 
@@ -1902,29 +1905,32 @@ SQLRETURN SQL_API SQLPutData( SQLHSTMT      hstmt,
 SQLRETURN SQL_API SQLCancel(SQLHSTMT hstmt)
 {
   MYSQL *second= NULL;
-  int error;
   DBC *dbc;
 
+
   CHECK_HANDLE(hstmt);
 
   dbc= ((STMT *)hstmt)->dbc;
-  error= myodbc_mutex_trylock(&dbc->lock);
+
+  LOCK_DBC_DEFER(dbc); // implicitly declares dlock variable without locking
 
   /* If there's no query going on, just close the statement. */
-  if (error == 0)
+  if (dlock.try_lock())
   {
-    myodbc_mutex_unlock(&dbc->lock);
+    /*
+      Lock is acquired. STMT can be closed safely.
+      Lock will be released automatically
+    */
     return my_SQLFreeStmt(hstmt, SQL_CLOSE);
   }
 
-  /* If we got a non-BUSY error, it's just an error. */
-  if (error != EBUSY)
-    return set_stmt_error((STMT *)hstmt, "HY000",
-                          "Unable to get connection mutex status", error);
-
   /*
     If the mutex was locked, we need to make a new connection and KILL the
-    ongoing query.
+    ongoing query. The mutex will be unlocked later automatically.
+
+    This is an entirely new connection and it should not
+    interfere with the existing one. Therefore, locking is not needed in
+    the following block.
   */
   second= mysql_init(second);
 
@@ -1941,7 +1947,7 @@ SQLRETURN SQL_API SQLCancel(SQLHSTMT hstmt)
   {
     char buff[40];
     /* buff is always big enough because max length of %lu is 15 */
-    sprintf(buff, "KILL /*!50000 QUERY */ %lu", mysql_thread_id(&dbc->mysql));
+    sprintf(buff, "KILL /*!50000 QUERY */ %lu", mysql_thread_id(dbc->mysql));
     if (mysql_real_query(second, buff, strlen(buff)))
     {
       mysql_close(second);
