@@ -1730,7 +1730,10 @@ SQLRETURN SQL_API SQLRowCount( SQLHSTMT hstmt,
 
     if ( stmt->result )
     {
-      /* for SetPos operations result is defined and they use direct execution */
+      if (stmt->fake_result)
+        *pcrow = stmt->result->row_count;
+      else
+        // for SetPos operations result is defined and they use direct execution
         *pcrow= (SQLLEN) affected_rows(stmt);
     }
     else
@@ -2436,7 +2439,7 @@ SQLRETURN SQL_API my_SQLExtendedFetch( SQLHSTMT             hstmt,
            lengths in ird*/
         if (stmt->lengths)
         {
-          fill_ird_data_lengths(stmt->ird, stmt->lengths + cur_row*stmt->result->field_count,
+          fill_ird_data_lengths(stmt->ird, stmt->lengths.get() + cur_row*stmt->result->field_count,
                                 stmt->result->field_count);
         }
         else
