@@ -1,30 +1,30 @@
-// Copyright (c) 2001, 2018, Oracle and/or its affiliates. All rights reserved. 
-// 
-// This program is free software; you can redistribute it and/or modify 
-// it under the terms of the GNU General Public License, version 2.0, as 
-// published by the Free Software Foundation. 
-// 
-// This program is also distributed with certain software (including 
-// but not limited to OpenSSL) that is licensed under separate terms, 
-// as designated in a particular file or component or in included license 
-// documentation. The authors of MySQL hereby grant you an 
-// additional permission to link the program and your derivative works 
-// with the separately licensed software that they have included with 
-// MySQL. 
-// 
-// Without limiting anything contained in the foregoing, this file, 
-// which is part of <MySQL Product>, is also subject to the 
-// Universal FOSS Exception, version 1.0, a copy of which can be found at 
-// http://oss.oracle.com/licenses/universal-foss-exception. 
-// 
-// This program is distributed in the hope that it will be useful, but 
-// WITHOUT ANY WARRANTY; without even the implied warranty of 
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
-// See the GNU General Public License, version 2.0, for more details. 
-// 
-// You should have received a copy of the GNU General Public License 
-// along with this program; if not, write to the Free Software Foundation, Inc., 
-// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
+// Copyright (c) 2001, 2018, Oracle and/or its affiliates. All rights reserved.
+//
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License, version 2.0, as
+// published by the Free Software Foundation.
+//
+// This program is also distributed with certain software (including
+// but not limited to OpenSSL) that is licensed under separate terms,
+// as designated in a particular file or component or in included license
+// documentation. The authors of MySQL hereby grant you an
+// additional permission to link the program and your derivative works
+// with the separately licensed software that they have included with
+// MySQL.
+//
+// Without limiting anything contained in the foregoing, this file,
+// which is part of <MySQL Product>, is also subject to the
+// Universal FOSS Exception, version 1.0, a copy of which can be found at
+// http://oss.oracle.com/licenses/universal-foss-exception.
+//
+// This program is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+// See the GNU General Public License, version 2.0, for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software Foundation, Inc.,
+// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /**
   @file  transact.c
@@ -72,15 +72,14 @@ static SQLRETURN my_transact(SQLHDBC hdbc, SQLSMALLINT CompletionType)
 
     MYLOG_DBC_QUERY(dbc, query);
 
-    myodbc_mutex_lock(&dbc->lock);
+    LOCK_DBC(dbc);
     if (check_if_server_is_alive(dbc) ||
-	mysql_real_query(&dbc->mysql,query,length))
+	mysql_real_query(dbc->mysql,query,length))
     {
       result= set_conn_error((DBC*)hdbc,MYERR_S1000,
-			     mysql_error(&dbc->mysql),
-			     mysql_errno(&dbc->mysql));
+			     mysql_error(dbc->mysql),
+			     mysql_errno(dbc->mysql));
     }
-    myodbc_mutex_unlock(&dbc->lock);
   }
   return(result);
 }
@@ -108,27 +107,25 @@ end_transaction(SQLSMALLINT HandleType,
 
   switch (HandleType) {
   case SQL_HANDLE_ENV:
+  {
     henv= (ENV *)Handle;
-    myodbc_mutex_lock(&henv->lock);
-    for (current= henv->connections; current; current= current->next)
+    LOCK_ENV(henv);
+    for (DBC *dbc : henv->conn_list)
     {
-        my_transact((DBC *)current->data, CompletionType);
+        my_transact(dbc, CompletionType);
     }
-    myodbc_mutex_unlock(&henv->lock);
     break;
-
+  }
   case SQL_HANDLE_DBC:
+  {
     hdbc= (DBC*)Handle;
 
 #ifndef _WIN32
-    myodbc_mutex_lock(&hdbc->env->lock);
+    LOCK_DBC(hdbc);
 #endif
     result= my_transact(hdbc, CompletionType);
-#ifndef _WIN32
-    myodbc_mutex_unlock(&hdbc->env->lock);
-#endif
     break;
-
+  }
   default:
     result= SQL_ERROR;
     ((STMT*)Handle)->set_error(MYERR_S1092,NULL,0);
