@@ -55,7 +55,8 @@ SQLGetDiagRecWImpl(SQLSMALLINT handle_type, SQLHANDLE handle,
                    SQLINTEGER *native_error, SQLWCHAR *message,
                    SQLSMALLINT message_max, SQLSMALLINT *message_len);
 SQLRETURN SQL_API
-SQLPrepareWImpl(SQLHSTMT hstmt, SQLWCHAR *str, SQLINTEGER str_len);
+SQLPrepareWImpl(SQLHSTMT hstmt, SQLWCHAR *str, SQLINTEGER str_len,
+                bool force_prepare);
 
 SQLRETURN SQL_API
 SQLSetConnectAttrWImpl(SQLHDBC hdbc, SQLINTEGER attribute,
@@ -284,7 +285,7 @@ SQLDescribeColW(SQLHSTMT hstmt, SQLUSMALLINT column,
 
   if (free_value == -1)
   {
-    set_mem_error(&stmt->dbc->mysql);
+    set_mem_error(stmt->dbc->mysql);
     return handle_connection_error(stmt);
   }
 
@@ -296,7 +297,7 @@ SQLDescribeColW(SQLHSTMT hstmt, SQLUSMALLINT column,
     {
       if (free_value)
         x_free(value);
-      set_mem_error(&stmt->dbc->mysql);
+      set_mem_error(stmt->dbc->mysql);
       return handle_connection_error(stmt);
     }
 
@@ -361,7 +362,7 @@ SQLExecDirectW(SQLHSTMT hstmt, SQLWCHAR *str, SQLINTEGER str_len)
 
   CHECK_HANDLE(hstmt);
 
-  if ((error= SQLPrepareWImpl(hstmt, str, str_len)))
+  if ((error= SQLPrepareWImpl(hstmt, str, str_len, false)))
     return error;
   error= my_SQLExecute((STMT *)hstmt);
 
@@ -848,12 +849,13 @@ SQLPrepareW(SQLHSTMT hstmt, SQLWCHAR *str, SQLINTEGER str_len)
 {
   CHECK_HANDLE(hstmt);
 
-  return SQLPrepareWImpl(hstmt, str, str_len);
+  return SQLPrepareWImpl(hstmt, str, str_len, true);
 }
 
 
 SQLRETURN SQL_API
-SQLPrepareWImpl(SQLHSTMT hstmt, SQLWCHAR *str, SQLINTEGER str_len)
+SQLPrepareWImpl(SQLHSTMT hstmt, SQLWCHAR *str, SQLINTEGER str_len,
+                bool force_prepare)
 {
   STMT *stmt= (STMT *)hstmt;
   uint errors;
@@ -863,10 +865,10 @@ SQLPrepareWImpl(SQLHSTMT hstmt, SQLWCHAR *str, SQLINTEGER str_len)
   if (errors)
   {
     x_free(conv);
-    return set_stmt_error(stmt, "22018", NULL, 0);
+    return stmt->set_error("22018", NULL, 0);
   }
 
-  return MySQLPrepare(hstmt, conv, str_len, true, false);
+  return MySQLPrepare(hstmt, conv, str_len, true, false, force_prepare);
 }
 
 
@@ -1021,7 +1023,7 @@ SQLSetConnectAttrWImpl(SQLHDBC hdbc, SQLINTEGER attribute,
     /* Verifying for incorrect val_len */
     if (value_len < 0 && value_len != SQL_NTS)
     {
-      return set_dbc_error(dbc, "HY090",
+      return dbc->set_error("HY090",
                   " StringLength argument was less "
                   "than 0 but was not SQL_NTS " , 0);
     }
@@ -1066,7 +1068,7 @@ SQLSetCursorNameW(SQLHSTMT hstmt, SQLWCHAR *name, SQLSMALLINT name_len)
   /* Character conversion problems are not tolerated. */
   if (errors)
   {
-    return set_stmt_error((STMT *)hstmt, "HY000",
+    return ((STMT *)hstmt)->set_error("HY000",
                           "Cursor name included characters that could not "
                           "be converted to connection character set", 0);
   }
@@ -1295,8 +1297,29 @@ SQLSetDescFieldW(SQLHDESC hdesc, SQLSMALLINT record, SQLSMALLINT field,
                  SQLPOINTER value, SQLINTEGER value_len)
 {
   CHECK_HANDLE(hdesc);
+  DESC *desc = (DESC*)hdesc;
+  SQLRETURN rc = SQL_SUCCESS;
+  SQLPOINTER val = value;
+  SQLCHAR *val8 = nullptr;
+  uint errors= 0;
 
-  return MySQLSetDescField(hdesc, record, field, value, value_len);
+  switch(field)
+  {
+    case SQL_DESC_NAME:
+      // Assume a string value, which needs conversion
+      val8= sqlwchar_as_sqlchar(desc->dbc->cxn_charset_info,
+                                (SQLWCHAR*)value, &value_len, &errors);
+
+      // Set SQL_NTS instead of the real length or type won't be recognized
+      value_len = SQL_NTS;
+      break;
+  }
+
+  rc = desc->set_field(record, field,
+                       val8 ? val8 : val,
+                       value_len);
+  x_free(val8);
+  return rc;
 }
 
 
