@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved.
+   Copyright (c) 2016, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -44,8 +44,9 @@
 #include <winsock2.h>  // struct timeval
 #endif                 /* _WIN32 */
 
-#undef min
-#undef max
+#ifdef max
+#undef max  // Visual Studio defines this macro
+#endif
 
 using UTC_clock = std::chrono::system_clock;
 
@@ -201,6 +202,32 @@ inline unsigned long long int my_micro_time() {
 #endif /* _WIN32 */
 }
 
+/**
+  Return time in milliseconds. Uses std::chrono::high_resolution_clock
+
+  @remark This function is to be used to measure time in
+          millisecond.
+
+  @retval Number of milliseconds since the Epoch, 1970-01-01 00:00:00 +0000
+  (UTC)
+*/
+inline unsigned long long int my_milli_time() {
+#ifdef _WIN32
+  return std::chrono::duration_cast<std::chrono::milliseconds>(
+             UTC_clock::now().time_since_epoch())
+      .count();
+#else
+  struct timeval t;
+  /*
+  The following loop is here because gettimeofday may fail on some systems
+  */
+  while (gettimeofday(&t, nullptr) != 0) {
+  }
+  return (static_cast<unsigned long long int>(t.tv_sec) * 1000 +
+          (t.tv_usec / 1000));
+#endif /* _WIN32 */
+}
+
 /**
   Convert microseconds since epoch to timeval.
   @param      micro_time  Microseconds.
@@ -208,8 +235,8 @@ inline unsigned long long int my_micro_time() {
 */
 inline void my_micro_time_to_timeval(std::uint64_t micro_time,
                                      struct timeval *tm) {
-  tm->tv_sec = micro_time / 1000000;
-  tm->tv_usec = micro_time % 1000000;
+  tm->tv_sec = static_cast<long>(micro_time / 1000000);
+  tm->tv_usec = static_cast<long>(micro_time % 1000000);
 }
 
 void get_date(char *to, int flag, time_t date);
