@@ -1,30 +1,24 @@
-// Copyright (c) 2008, 2017, Oracle and/or its affiliates. All rights reserved. 
-// 
-// This program is free software; you can redistribute it and/or modify 
-// it under the terms of the GNU General Public License, version 2.0, as 
-// published by the Free Software Foundation. 
-// 
-// This program is also distributed with certain software (including 
-// but not limited to OpenSSL) that is licensed under separate terms, 
-// as designated in a particular file or component or in included license 
-// documentation. The authors of MySQL hereby grant you an 
-// additional permission to link the program and your derivative works 
-// with the separately licensed software that they have included with 
-// MySQL. 
-// 
-// Without limiting anything contained in the foregoing, this file, 
-// which is part of MySQL Server, is also subject to the 
-// Universal FOSS Exception, version 1.0, a copy of which can be found at 
-// http://oss.oracle.com/licenses/universal-foss-exception. 
-// 
-// This program is distributed in the hope that it will be useful, but 
-// WITHOUT ANY WARRANTY; without even the implied warranty of 
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
-// See the GNU General Public License, version 2.0, for more details. 
-// 
-// You should have received a copy of the GNU General Public License 
-// along with this program; if not, write to the Free Software Foundation, Inc., 
-// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
+/* Copyright (c) 2008, 2021, Oracle and/or its affiliates.
+
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License, version 2.0,
+  as published by the Free Software Foundation.
+
+  This program is also distributed with certain software (including
+  but not limited to OpenSSL) that is licensed under separate terms,
+  as designated in a particular file or component or in included license
+  documentation.  The authors of MySQL hereby grant you an additional
+  permission to link the program and your derivative works with the
+  separately licensed software that they have included with MySQL.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License, version 2.0, for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, write to the Free Software
+  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */
 
 #ifndef COMPONENTS_SERVICES_PSI_STATEMENT_BITS_H
 #define COMPONENTS_SERVICES_PSI_STATEMENT_BITS_H
@@ -33,6 +27,8 @@
 #include <stddef.h> /* size_t */
 #endif
 
+#include <mysql/components/services/bits/psi_bits.h>
+
 /**
   @file
   Performance schema instrumentation interface.
@@ -53,16 +49,23 @@ typedef unsigned int PSI_statement_key;
 /**
   @def PSI_STATEMENT_VERSION_1
   Performance Schema Statement Interface number for version 1.
-  This version is supported.
+  This version is deprecated.
 */
 #define PSI_STATEMENT_VERSION_1 1
 
+/**
+  @def PSI_STATEMENT_VERSION_2
+  Performance Schema Statement Interface number for version 2.
+  This version is supported.
+*/
+#define PSI_STATEMENT_VERSION_2 2
+
 /**
   @def PSI_CURRENT_STATEMENT_VERSION
   Performance Schema Statement Interface number for the most recent version.
-  The most current version is @c PSI_STATEMENT_VERSION_1
+  The most current version is @c PSI_STATEMENT_VERSION_2
 */
-#define PSI_CURRENT_STATEMENT_VERSION 1
+#define PSI_CURRENT_STATEMENT_VERSION 2
 
 /**
   Interface for an instrumented statement.
@@ -230,6 +233,7 @@ typedef void (*register_statement_v1_t)(const char *category,
   @param state data storage for the locker
   @param key the statement instrumentation key
   @param charset client character set
+  @param sp_share Parent stored procedure share, if any.
   @return a statement locker, or NULL
 */
 typedef struct PSI_statement_locker *(*get_thread_statement_locker_v1_t)(
@@ -271,6 +275,15 @@ typedef void (*set_statement_text_v1_t)(struct PSI_statement_locker *locker,
                                         const char *text,
                                         unsigned int text_len);
 
+/**
+  Set a statement query id.
+  Introduced in MySQL 8.0.14
+  @param locker the statement locker
+  @param query_id the query id
+*/
+typedef void (*set_statement_query_id_t)(struct PSI_statement_locker *locker,
+                                         unsigned long long query_id);
+
 /**
   Set a statement event lock time.
   @param locker the statement locker
@@ -408,12 +421,18 @@ typedef void (*end_statement_v1_t)(struct PSI_statement_locker *locker,
 
 /**
   Get a prepare statement.
-  @param locker a statement locker for the running thread.
+  @param identity Prepared statement identity, typically a memory address.
+  @param stmt_id Prepared statement identifier.
+  @param locker A statement locker for the running thread.
+  @param stmt_name Prepared statement name.
+  @param stmt_name_length Prepared statement name length.
+  @param sql_text Query text.
+  @param sql_text_length Query text length.
 */
 typedef PSI_prepared_stmt *(*create_prepared_stmt_v1_t)(
     void *identity, unsigned int stmt_id, PSI_statement_locker *locker,
-    const char *stmt_name, size_t stmt_name_length, const char *name,
-    size_t length);
+    const char *stmt_name, size_t stmt_name_length, const char *sql_text,
+    size_t sql_text_length);
 
 /**
   destroy a prepare statement.
