@@ -1,30 +1,30 @@
-# Copyright (c) 2007, 2020, Oracle and/or its affiliates. All rights reserved.
-# 
-# This program is free software; you can redistribute it and/or modify 
-# it under the terms of the GNU General Public License, version 2.0, as 
-# published by the Free Software Foundation. 
+# Copyright (c) 2007, 2021, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is also distributed with certain software (including 
-# but not limited to OpenSSL) that is licensed under separate terms, 
-# as designated in a particular file or component or in included license 
-# documentation. The authors of MySQL hereby grant you an 
-# additional permission to link the program and your derivative works 
-# with the separately licensed software that they have included with 
-# MySQL. 
-# 
-# Without limiting anything contained in the foregoing, this file, 
-# which is part of MySQL Connector/ODBC, is also subject to the 
-# Universal FOSS Exception, version 1.0, a copy of which can be found at 
-# http://oss.oracle.com/licenses/universal-foss-exception. 
-# 
-# This program is distributed in the hope that it will be useful, but 
-# WITHOUT ANY WARRANTY; without even the implied warranty of 
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
-# See the GNU General Public License, version 2.0, for more details. 
-# 
-# You should have received a copy of the GNU General Public License 
-# along with this program; if not, write to the Free Software Foundation, Inc., 
-# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0, as
+# published by the Free Software Foundation.
+#
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms,
+# as designated in a particular file or component or in included license
+# documentation. The authors of MySQL hereby grant you an
+# additional permission to link the program and your derivative works
+# with the separately licensed software that they have included with
+# MySQL.
+#
+# Without limiting anything contained in the foregoing, this file,
+# which is part of MySQL Connector/ODBC, is also subject to the
+# Universal FOSS Exception, version 1.0, a copy of which can be found at
+# http://oss.oracle.com/licenses/universal-foss-exception.
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the GNU General Public License, version 2.0, for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 
 ##############################################################################
@@ -44,6 +44,8 @@
 %global license_files	LICENSE.txt README.txt
 %endif
 
+%global cmake3  cmake%{?el6:3}%{?el7:3}
+
 # Use rpmbuild -ba --define 'shared_mysqlclient 1' ... to build shared
 %{!?shared_mysqlclient: %global static_mysqlclient 1}
 
@@ -56,17 +58,20 @@
 Summary:	An ODBC @CONNECTOR_BASE_VERSION@ driver for MySQL - driver package
 Name:		mysql-connector-odbc%{?product_suffix}
 Version:	@CONNECTOR_NODASH_VERSION@
-Release:	1%{?commercial:.1}%{?dist}
+Release:	1%{?fedora:0}%{?commercial:.1}%{?dist}
 License:	Copyright (c) 2000, @CURRENT_YEAR@, %{mysql_vendor}. All rights reserved.  Under %{license_type} license as shown in the Description field.
 Source0:	http://cdn.mysql.com/Downloads/Connector-ODBC/@CONNECTOR_BASE_VERSION@/%{name}-@CONNECTOR_VERSION@-src.tar.gz
 URL:		http://www.mysql.com/
 Group:		Applications/Databases
 Vendor:		%{mysql_vendor}
 Packager:	%{mysql_vendor} Product Engineering Team <mysql-build@oss.oracle.com>
-BuildRequires:	cmake 
+BuildRequires:	cmake
 %{?shared_mysqlclient:BuildRequires: mysql-community-devel}
 BuildRequires:	unixODBC-devel
-BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
+BuildRequires:  gtk2-devel
+%if 0%{?rhel} != 6 && 0%{?suse_version} != 1315
+BuildRequires:  gtk3-devel
+%endif
 
 %if 0%{?odbc_gui}
 %package setup
@@ -129,7 +134,7 @@ The test suite for MySQL ODBC.
 mkdir release
 pushd release
 export CFLAGS="%{optflags}"
-cmake -G "Unix Makefiles"   \
+%{cmake3} -G "Unix Makefiles"   \
     -DRPM_BUILD=1           \
     -DCMAKE_INSTALL_PREFIX=%{_prefix} \
 %if 0%{?odbc_gui}
@@ -142,7 +147,7 @@ cmake -G "Unix Makefiles"   \
     %{?cmake_opt_extra}      \
     ..
 
-# Note that the ".." needs to be last, in case some arguments expands to 
+# Note that the ".." needs to be last, in case some arguments expands to
 # the empty string, and then "cmake" thinks is "current directory"
 
 make  %{?_smp_mflags} VERBOSE=1
@@ -184,7 +189,7 @@ popd
 # deinstall before reinstall to change anything
 # ----------------------------------------------------------------------
 
-%post 
+%post
 if [ -x /usr/bin/myodbc-installer ]; then
     /usr/bin/myodbc-installer -a -d -n "MySQL ODBC @CONNECTOR_BASE_VERSION@ Unicode Driver" -t "DRIVER=%{_libdir}/libmyodbc8w.so"
     /usr/bin/myodbc-installer -a -d -n "MySQL ODBC @CONNECTOR_BASE_VERSION@ ANSI Driver"    -t "DRIVER=%{_libdir}/libmyodbc8a.so"
@@ -199,7 +204,7 @@ fi
 %endif
 
 # ----------------------------------------------------------------------
-# DEREGISTER DRIVER 
+# DEREGISTER DRIVER
 # ----------------------------------------------------------------------
 
 # Removing the driver package, we simply orphan any related DSNs
