@@ -134,8 +134,6 @@
 #define IDC_EDIT_default_auth           10054
 #define IDC_CHOOSER_plugin_dir          10055
 #define IDC_CHECK_no_date_overflow      10057
-#define IDC_CHECK_no_tls_1              10058
-#define IDC_CHECK_no_tls_1_1            10059
 #define IDC_CHECK_no_tls_1_2            10060
 #define IDC_CHECK_no_tls_1_3            10061
 #define IDC_EDIT_sslmode                10062
