@@ -88,10 +88,9 @@ DECLARE_TEST(t_bug34272)
 
   ok_stmt(hstmt, SQLGetData(hstmt, 6, SQL_C_CHAR, dummy, col6+1, &length));
   /* Can be "integer unsigned" (16) or "int unsigned" (12) */
-  is(length == 16 || length == 12);
-  is(strncmp(dummy, "int unsigned", 12) == 0 ||
-     strncmp(dummy, "integer unsigned", 16) == 0 ||
-     strncmp(dummy, "int(10) unsigned", 16) == 0);
+  is(length == 16 || length == 3);
+  is(strncmp(dummy, "integer unsigned", 16) == 0 ||
+     strncmp(dummy, "int", 3) == 0);
 
   ok_stmt(hstmt, SQLGetData(hstmt, 18, SQL_C_CHAR, dummy, col18+1, &length));
   is_num(length,3);
@@ -280,6 +279,7 @@ DECLARE_TEST(t_bug50195)
   int         i;
   SQLCHAR     priv[12];
   SQLLEN      len;
+  SQLCHAR     buffer[MAX_NAME_LEN];
 
   /*
     The patch for this issue can only work with Information_Schema.
@@ -288,23 +288,29 @@ DECLARE_TEST(t_bug50195)
   if (myoption && (1 << 30))
     return OK;
 
+  (void)SQLExecDirect(hstmt, (SQLCHAR *)"DROP USER `bug50195`@`%`", SQL_NTS);
   (void)SQLExecDirect(hstmt, (SQLCHAR *)"DROP USER `bug50195`@`127.0.0.1`", SQL_NTS);
   (void)SQLExecDirect(hstmt, (SQLCHAR *)"DROP USER `bug50195`@`localhost`", SQL_NTS);
 
+  ok_sql(hstmt, "CREATE USER `bug50195`@`%` IDENTIFIED BY 'a'");
   ok_sql(hstmt, "CREATE USER `bug50195`@`127.0.0.1` IDENTIFIED BY 'a'");
   ok_sql(hstmt, "CREATE USER `bug50195`@`localhost` IDENTIFIED BY 'a'");
+  ok_sql(hstmt, "grant all on *.* to `bug50195`@`%`");
   ok_sql(hstmt, "grant all on *.* to `bug50195`@`127.0.0.1`");
   ok_sql(hstmt, "grant all on *.* to `bug50195`@`localhost`");
 
-  ok_sql(hstmt, "revoke select on *.* from bug50195@127.0.0.1");
-  ok_sql(hstmt, "revoke select on *.* from bug50195@localhost");
+  ok_sql(hstmt, "revoke select on *.* from bug50195@`%`");
+  ok_sql(hstmt, "revoke select on *.* from bug50195@`127.0.0.1`");
+  ok_sql(hstmt, "revoke select on *.* from bug50195@`localhost`");
 
   /* revoking "global" select is enough, but revoking smth from mysql.tables_priv
      to have not empty result of SQLTablePrivileges */
-  ok_sql(hstmt, "grant all on mysql.tables_priv to bug50195@127.0.0.1");
-  ok_sql(hstmt, "grant all on mysql.tables_priv to bug50195@localhost");
-  ok_sql(hstmt, "revoke select on mysql.tables_priv from bug50195@127.0.0.1");
-  ok_sql(hstmt, "revoke select on mysql.tables_priv from bug50195@localhost");
+  ok_sql(hstmt, "grant all on mysql.tables_priv to bug50195@`%`");
+  ok_sql(hstmt, "grant all on mysql.tables_priv to bug50195@`127.0.0.1`");
+  ok_sql(hstmt, "grant all on mysql.tables_priv to bug50195@`localhost`");
+  ok_sql(hstmt, "revoke select on mysql.tables_priv from bug50195@`%`");
+  ok_sql(hstmt, "revoke select on mysql.tables_priv from bug50195@`127.0.0.1`");
+  ok_sql(hstmt, "revoke select on mysql.tables_priv from bug50195@`localhost`");
 
   ok_sql(hstmt, "FLUSH PRIVILEGES");
 
@@ -326,8 +332,9 @@ DECLARE_TEST(t_bug50195)
 
   free_basic_handles(&henv1, &hdbc1, &hstmt1);
 
-  ok_sql(hstmt, "DROP USER bug50195@127.0.0.1");
-  ok_sql(hstmt, "DROP USER bug50195@localhost");
+  ok_sql(hstmt, "DROP USER bug50195@`%`");
+  ok_sql(hstmt, "DROP USER bug50195@`127.0.0.1`");
+  ok_sql(hstmt, "DROP USER bug50195@`localhost`");
 
   return OK;
 }
@@ -1335,8 +1342,77 @@ DECLARE_TEST(t_bug32504915)
   return OK;
 }
 
+/*
+  SQLColumns() reports wrong type name with column length
+*/
+DECLARE_TEST(t_bug33599093)
+{
+  char *type_list[] =
+  {
+    "char", "varchar", "decimal", "bit", "binary", "varbinary", "tinyint"
+  };
+  int idx = 0;
+
+  ok_sql(hstmt, "DROP TABLE IF EXISTS tab33599093");
+  ok_sql(hstmt, "CREATE TABLE tab33599093 (c1 char(16), c2 varchar(32),"
+                "c3 decimal(5,3), c4 bit(32), c5 binary(8), c6 varbinary(16),"
+                "c7 tinyint unsigned)");
+
+  ok_stmt(hstmt, SQLColumns(hstmt, NULL, SQL_NTS, NULL, SQL_NTS,
+    (SQLCHAR *)"tab33599093", SQL_NTS, NULL, 0));
+
+  while(SQL_SUCCESS == SQLFetch(hstmt))
+  {
+    SQLCHAR type_name[32] = { 0 };
+
+    // _no_i_s cannot filter out unsigned types, so skip it
+    if (idx > 5 && (myoption & (1 << 30)))
+      continue;
+
+    is_str(my_fetch_str(hstmt, type_name, 6), type_list[idx], SQL_NTS);
+    is_num(strlen(type_name), strlen(type_list[idx]));
+    ++idx;
+  }
+
+  ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
+  ok_sql(hstmt, "DROP TABLE IF EXISTS tab33599093");
+  return OK;
+}
+
+
+/*
+  Bug #33788407 -  Unable to add mysql views to ms access.
+  (Cannot define Field more than once)
+*/
+
+DECLARE_TEST(t_bug33788407)
+{
+  ok_sql(hstmt, "DROP DATABASE IF EXISTS db_33788407_01");
+  ok_sql(hstmt, "DROP DATABASE IF EXISTS db_33788407_02");
+
+  ok_sql(hstmt, "CREATE DATABASE db_33788407_01");
+  ok_sql(hstmt, "CREATE DATABASE db_33788407_02");
+
+  ok_sql(hstmt, "CREATE TABLE db_33788407_01.test_table_a (id INT)");
+  ok_sql(hstmt, "CREATE TABLE db_33788407_02.test_table_a (id INT)");
+
+  DECLARE_BASIC_HANDLES(henv1, hdbc1, hstmt1);
+  is(OK == alloc_basic_handles_with_opt(&henv1, &hdbc1, &hstmt1, NULL,
+                                        NULL, NULL, "db_33788407_02", NULL));
+
+  ok_stmt(hstmt1, SQLColumns(hstmt1, NULL, 0, NULL, 0, "test_table_a", SQL_NTS,
+    NULL, 0));
+
+  // The result should have one and only one row.
+  is(1 == my_print_non_format_result(hstmt1));
+
+  free_basic_handles(&henv1, &hdbc1, &hstmt1);
+  return OK;
+}
+
 
 BEGIN_TESTS
+  ADD_TEST(t_bug33788407)
   ADD_TEST(t_bug32504915)
   ADD_TEST(t_sqlprocedurecolumns)
   ADD_TEST(t_bug57182)
@@ -1359,6 +1435,7 @@ BEGIN_TESTS
   ADD_TEST(t_sqlcolumns_after_select)
   ADD_TEST(t_bug14555713)
   ADD_TEST(t_bug69448)
+  ADD_TEST(t_bug33599093)
 END_TESTS
 
 myoption &= ~(1 << 30);
