@@ -287,16 +287,24 @@ DECLARE_TEST(t_bug28385722)
   SQLUINTEGER schema_usage = 0;
   SQLSMALLINT val_len = 0;
 
-  ok_con(hdbc, SQLGetInfo(hdbc, SQL_MAX_SCHEMA_NAME_LEN, &schema_len,
-                          sizeof(schema_len), &val_len));
-  is_num(schema_len, 64);
+  DECLARE_BASIC_HANDLES(henv1, hdbc1, hstmt1);
+  SQLCHAR   conn[512];
 
-  ok_con(hdbc, SQLGetInfo(hdbc, SQL_SCHEMA_USAGE, &schema_usage,
+  is(OK == alloc_basic_handles_with_opt(&henv1, &hdbc1, &hstmt1, NULL,
+                                        NULL, NULL, NULL, "NO_SCHEMA=0"));
+
+  ok_con(hdbc, SQLGetInfo(hdbc1, SQL_MAX_SCHEMA_NAME_LEN, &schema_len,
+                          sizeof(schema_len), &val_len));
+  is(schema_len > 63);
+
+  ok_con(hdbc, SQLGetInfo(hdbc1, SQL_SCHEMA_USAGE, &schema_usage,
                           sizeof(schema_usage), &val_len));
   is_num(schema_usage, SQL_SU_DML_STATEMENTS | SQL_SU_PROCEDURE_INVOCATION |
          SQL_SU_TABLE_DEFINITION | SQL_SU_INDEX_DEFINITION |
          SQL_SU_PRIVILEGE_DEFINITION);
 
+  free_basic_handles(&henv1, &hdbc1, &hstmt1);
+
   return OK;
 }
 
@@ -717,31 +725,30 @@ DECLARE_TEST(t_getkeywordinfo)
   ok_con(hdbc, SQLGetInfo(hdbc, SQL_KEYWORDS, keywords,
                           sizeof(keywords), &pccol));
 
-  /* We do not check versions older than 5.5 */
-  if (mysql_min_version(hdbc, "5.7", 3))
+  /* We do not check versions older than 5.7 */
+  if (mysql_min_version(hdbc, "8.0.22", 6))
+  {
+    is(strstr(keywords, "SOURCE_HEARTBEAT_PERIOD"));
+    is(strstr(keywords, "SOURCE_BIND"));
+  }
+  else if (mysql_min_version(hdbc, "5.7", 3))
   {
     is(strstr(keywords, "NONBLOCKING"));
-  }
-  else if (mysql_min_version(hdbc, "5.6", 3))
-  {
     is(strstr(keywords, "GET"));
     is(strstr(keywords, "IO_AFTER_GTIDS"));
     is(strstr(keywords, "IO_BEFORE_GTIDS"));
-    is(strstr(keywords, "MASTER_BIND"));
     is(strstr(keywords, "ONE_SHOT"));
     is(strstr(keywords, "PARTITION"));
     is(strstr(keywords, "SQL_AFTER_GTIDS"));
     is(strstr(keywords, "SQL_BEFORE_GTIDS"));
-  }
-  else if (mysql_min_version(hdbc, "5.5", 3))
-  {
     is(strstr(keywords, "GENERAL"));
     is(strstr(keywords, "IGNORE_SERVER_IDS"));
-    is(strstr(keywords, "MASTER_HEARTBEAT_PERIOD"));
     is(strstr(keywords, "MAXVALUE"));
     is(strstr(keywords, "RESIGNAL"));
     is(strstr(keywords, "SIGNAL"));
     is(strstr(keywords, "SLOW"));
+    is(strstr(keywords, "\x4D\x41\x53\x54\x45\x52_HEARTBEAT_PERIOD"));
+    is(strstr(keywords, "\x4D\x41\x53\x54\x45\x52_BIND"));
   }
 
   return OK;
@@ -818,9 +825,9 @@ BEGIN_TESTS
   ADD_TEST(t_stmt_attr_status)
   ADD_TEST(t_msdev_bug)
   ADD_TEST(t_bug28657)
-#ifndef USE_IODBC
   ADD_TEST(t_bug30626)
   ADD_TEST(t_bug14639)
+#ifndef USE_IODBC
   ADD_TEST(t_getkeywordinfo)
 #endif
   ADD_TEST(t_bug31055)
